Stan Math Library: stan/math/prim/mat/vectorize/apply_scalar_unary.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
apply_scalar_unary.hpp File Reference
`#include <Eigen/Dense>`
`#include <vector>`

Go to the source code of this file.

## Classes
struct | stan::math::apply_scalar_unary< F, T >
| Base template class for vectorization of unary scalar functions defined by a template class `F` to a scalar, standard library vector, or Eigen dense matrix expression template. More...
struct | stan::math::apply_scalar_unary< F, double >
| Template specialization for vectorized functions applying to double arguments. More...
struct | stan::math::apply_scalar_unary< F, int >
| Template specialization for vectorized functions applying to integer arguments. More...
struct | stan::math::apply_scalar_unary< F, std::vector< T > >
| Template specialization for vectorized functions applying to standard vector containers. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.